@@ -128,7 +128,8 @@ else:
 class IMApp:
     def __init__(self, dbfile: str, exec_by_ibus: bool) -> None:
         if DEBUG_LEVEL > 1:
-            LOGGER.debug('IMApp.__init__(exec_by_ibus=%s)\n', exec_by_ibus)
+            LOGGER.debug('IMApp.__init__(dbfile=%s, exec_by_ibus=%s)\n',
+                         dbfile, exec_by_ibus)
         self.__mainloop = GLib.MainLoop()
         self.__bus: IBus.Bus = IBus.Bus()
         self.__bus.connect("disconnected", self.__bus_destroy_cb)
@@ -229,7 +230,9 @@ def cleanup(ima_ins: IMApp) -> None:
 def indent(element: Any, level: int = 0) -> None:
     '''Use to format xml Element pretty :)'''
     i = "\n" + level*"    "
-    if element:
+    if element is None:
+        return
+    if len(element):
         if not element.text or not element.text.strip():
             element.text = i + "    "
         for subelement in element:
@@ -278,7 +281,9 @@ def write_xml() -> None:
         # getdefaultlocale() returns something like ('ja_JP', 'UTF-8').
         # In case of C/POSIX locale it returns (None, None)
         locale.setlocale(locale.LC_ALL, '')
-        _locale = locale.getlocale(locale.LC_MESSAGES)[0].lower()
+        _locale = locale.getlocale(locale.LC_MESSAGES)[0]
+        if _locale:
+            _locale = _locale.lower()
         if not _locale:
             _locale = 'en'
         _longname.text = _sq_db.ime_properties.get(
@@ -366,6 +371,7 @@ def main() -> None:
     LOGGER.addHandler(log_handler)
     LOGGER.info('********** STARTING **********')
 
+    IBus.init()
     if _ARGS.daemon:
         if os.fork():
             sys.exit()
@@ -373,7 +379,7 @@ def main() -> None:
         if os.access(_ARGS.db, os.F_OK):
             db = _ARGS.db
         else:
-            db = '%s%s%s' % (DB_DIR,
+            db = '{}{}{}'.format(DB_DIR,
                              os.path.sep,
                              os.path.basename(_ARGS.db))
     else:
